#ifndef _LCD_TEST_H
#define _LCD_TEST_H

extern "C"
{
	BOOL KernelIoControl(DWORD dwIoControlCode, LPVOID lpInBuf, DWORD nInBufSize, LPVOID lpOutBuf, DWORD nOutBufSize, LPDWORD lpBytesReturned);
}
//
// IOCTL info, needs to be visible for application
//

#define SPI_IOCTL_INDEX									0x0870

#define IOCTL_SPI_TRANSACT								CTL_CODE( FILE_DEVICE_UNKNOWN,  \
                                                        SPI_IOCTL_INDEX + 0,       \
                                                        METHOD_BUFFERED,                \
                                                        FILE_ANY_ACCESS)

#define IOCTL_SPI_GET_DRIVER_IFC						CTL_CODE( FILE_DEVICE_UNKNOWN,  \
                                                        SPI_IOCTL_INDEX + 1,       \
                                                        METHOD_BUFFERED,                \
                                                        FILE_ANY_ACCESS)

#define IOCTL_SPI_REGISTER_CONFIGURATION				CTL_CODE( FILE_DEVICE_UNKNOWN,  \
                                                        SPI_IOCTL_INDEX + 2,       \
                                                        METHOD_BUFFERED,                \
                                                        FILE_ANY_ACCESS)

//------------------------------------------------------------------------------
//
//  Structs for SPI configuration and transaction
//


typedef struct _SPITransaction
{
    /* input: */
	DWORD	mTransactions;
	DWORD	*mWriteBuffer;
    /* output: */
    DWORD	*mReadBuffer;
} SPITRANS;

enum	POLARITY	{LOW_INACTIVE, HIGH_INACTIVE};

typedef struct{
	DWORD	dwDataSize;//must be in the range of [4,32]
	DWORD	dwClockRate;//in KHz, must be in the range of [4, 13*1024]
	POLARITY	ClockPol;
	POLARITY	ChipSelectPol;
	BOOL	bTxTristate;
	BOOL	ClkPhaseHalfCycle;
	BOOL	bCSExternal;//Is Chip Select a standard GPIO?
	DWORD	dwGpioNum;//Valid if bCSExternal is TRUE
}	SPI_SLAVE_CONFIG;
//------------------------------------------------------------------------------
//
//  Functions: LCDxxx
//------------------------------------------------------------------------------
//
//  Functions: LCDxxx for accessing LCD from user space via IOCTLs
//------------------------------------------------------------------------------

__inline HANDLE SPIUserOpen(TCHAR *strName)
{
    HANDLE hDevice;
	hDevice = CreateFile (strName, 0, 0, NULL, OPEN_ALWAYS | CREATE_NEW, 0, NULL);
    return hDevice;
}
__inline void SPIUserClose(HANDLE hContext)
{
	if(hContext == NULL)
		return;
	CloseHandle(hContext);
}
__inline BOOL SPIUserTransact(HANDLE hDevice, SPITRANS* pTrans)
{
	BOOL iRet;
	DWORD BytesWritten;
	if(hDevice == NULL)
		return FALSE;
	iRet = DeviceIoControl (hDevice, IOCTL_SPI_TRANSACT, NULL, 0, pTrans, sizeof(SPITRANS), &BytesWritten, NULL);
	return (iRet && BytesWritten == sizeof(SPITRANS));
}

__inline BOOL SPIUserSetConfiguration(HANDLE hDevice, SPI_SLAVE_CONFIG* Settings)
{
	if(hDevice == NULL)
		return FALSE;
	return DeviceIoControl (hDevice, IOCTL_SPI_REGISTER_CONFIGURATION, 
		Settings, sizeof(SPI_SLAVE_CONFIG), NULL, 0, NULL, NULL);	
}


#endif